import { ref } from "vue";
import { useCookies } from '@vueuse/integrations/useCookies'

const cookies = useCookies(['session']);

const sessionId = ref<string>();

export const useSession = () => {
    const setSessionId = (id: string) => {
        cookies.set('session', id);
        sessionId.value = id;
    }

    const getSessionId = (): string | undefined => sessionId.value;

    const initializeSessionId = (): void => {
        if (!sessionId.value) {
            const cookieSessionId = cookies.get('session');
            if (cookieSessionId) {
                setSessionId(cookieSessionId);
            }
        }
    };

    return { initializeSessionId, setSessionId, getSessionId };
}